@@ -8,6 +8,7 @@ pub fn derive_helper(input: proc_macro2::TokenStream) -> TokenStream {
 	let identifier = derive_input.ident.clone();
 	let data = derive_input.data.clone();
 	let attributes = derive_input.attrs.clone();
+	let parameters = Parameters::from(derive_input.generics.params.clone());
 
 	let options = Options::from(attributes);
 
@@ -18,7 +19,7 @@ pub fn derive_helper(input: proc_macro2::TokenStream) -> TokenStream {
 			
 			let fields = data_struct.fields;
 		
-			struct_helper(identifier, fields, options)
+			struct_helper(identifier, parameters, fields, options)
 
 		},
 		
@@ -26,7 +27,7 @@ pub fn derive_helper(input: proc_macro2::TokenStream) -> TokenStream {
 	
 			let variants = data_enum.variants.into_iter().collect();			
 
-			enum_helper(identifier, variants, options)
+			enum_helper(identifier, parameters, variants, options)
 				
 		},
 		
